package info.textgrid.middleware.test;

import static org.junit.Assert.assertTrue;
import org.junit.Test;
import info.textgrid.middleware.OAIPMHUtilities;

/**
 *
 */
public class TestOAIPMHUtilities {

  /**
   * 
   */
  @Test
  public void testOmitPrefixFromIdentifier() {

    // Check Handle IDs (dhrep).
    String id1 = "hdl:21.11113/0000-000B-C8EF-7";
    String exp1 = "21.11113/0000-000B-C8EF-7";
    String res1 = OAIPMHUtilities.omitPrefixFromIdentifier(id1);
    if (!res1.equals(exp1)) {
      System.out.println(res1 + "!=" + exp1);
      assertTrue(false);
    }

    // Check tgrep set IDs (do not filter project: prefix!).
    String id2 = "project:TGPR-2c283391-6ed5-70b4-2e5e-5501c856bca9";
    String exp2 = "project:TGPR-2c283391-6ed5-70b4-2e5e-5501c856bca9";
    String res2 = OAIPMHUtilities.omitPrefixFromIdentifier(id2);
    if (!res2.equals(exp2)) {
      System.out.println(res2 + "!=" + exp2);
      assertTrue(false);
    }

    // Check tgrep identifier.
    String id3 = "textgrid:24gv8.0";
    String exp3 = "24gv8.0";
    String res3 = OAIPMHUtilities.omitPrefixFromIdentifier(id3);
    if (!res3.equals(exp3)) {
      System.out.println(res3 + "!=" + exp3);
      assertTrue(false);
    }

    // Check unknown prefix.
    String id4 = "urgli:furgli";
    String exp4 = "urgli:furgli";
    String res4 = OAIPMHUtilities.omitPrefixFromIdentifier(id4);
    if (!res4.equals(exp4)) {
      System.out.println(res4 + "!=" + exp4);
      assertTrue(false);
    }

    // Check no prefix.
    String id5 = "URGLARGLAUA";
    String exp5 = "URGLARGLAUA";
    String res5 = OAIPMHUtilities.omitPrefixFromIdentifier(id5);
    if (!res5.equals(exp5)) {
      System.out.println(res5 + "!=" + exp5);
      assertTrue(false);
    }

    // Check **: prefix.
    String id6 = "**:21.T11991/0000-001C-2AA6-8";
    String exp6 = "**:21.T11991/0000-001C-2AA6-8";
    String res6 = OAIPMHUtilities.omitPrefixFromIdentifier(id6);
    if (!res6.equals(exp6)) {
      System.out.println(res6 + "!=" + exp6);
      assertTrue(false);
    }

    // Check ** prefix.
    String id7 = "**21.T11991/0000-001C-2AA6-8";
    String exp7 = "**21.T11991/0000-001C-2AA6-8";
    String res7 = OAIPMHUtilities.omitPrefixFromIdentifier(id7);
    if (!res7.equals(exp7)) {
      System.out.println(res7 + "!=" + exp7);
      assertTrue(false);
    }
  }

  /**
   * 
   */
  @Test
  public void testGetSetSpec() {

    String id = "hdl:21.T11991/0000-001B-4C00-E";

    // Set is empty.
    String set = "";
    String exp = "hdl:21.T11991/0000-001B-4C00-E";
    String setSpec = OAIPMHUtilities.getSetSpec(set, "hdl:", id);

    if (!setSpec.equals(exp)) {
      System.out.println(setSpec + " != " + exp);
      assertTrue(false);
    }

    // Set is prefix only.
    set = "hdl:";
    exp = "hdl:21.T11991/0000-001B-4C00-E";
    setSpec = OAIPMHUtilities.getSetSpec(set, "hdl:", id);

    if (!setSpec.equals(exp)) {
      System.out.println(setSpec + " != " + exp);
      assertTrue(false);
    }

    // Set is NOT empty.
    set = "project:53281-3452-34-5";
    exp = "project:53281-3452-34-5";
    setSpec = OAIPMHUtilities.getSetSpec(set, "project:", id);

    if (!setSpec.equals(exp)) {
      System.out.println(setSpec + " != " + exp);
      assertTrue(false);
    }
  }

  /**
   * 
   */
  @Test
  public void testGetTextGridBaseURI() {

    String uriExpected = "textgrid:12345";

    String uri = "textgrid:12345.13";
    String baseURI = OAIPMHUtilities.getTextGridBaseURI(uri);
    if (!baseURI.equals(uriExpected)) {
      System.out.println(baseURI + " != " + uriExpected);
      assertTrue(false);
    }

    uri = "textgrid:12345.1";
    baseURI = OAIPMHUtilities.getTextGridBaseURI(uri);
    if (!baseURI.equals(uriExpected)) {
      System.out.println(baseURI + " != " + uriExpected);
      assertTrue(false);
    }

    uri = "textgrid:12345";
    baseURI = OAIPMHUtilities.getTextGridBaseURI(uri);
    if (!baseURI.equals(uriExpected)) {
      System.out.println(baseURI + " != " + uriExpected);
      assertTrue(false);
    }

    uri = "textgrid:12345.3847";
    baseURI = OAIPMHUtilities.getTextGridBaseURI(uri);
    if (!baseURI.equals(uriExpected)) {
      System.out.println(baseURI + " != " + uriExpected);
      assertTrue(false);
    }
  }

  /**
   * 
   */
  @Test
  public void testGetTextGridRevisionURI() {

    String uriExpected = "textgrid:12345.0";
    String uri = "textgrid:12345";
    String revisionURI = OAIPMHUtilities.getTextGridRevisionURI(uri);
    if (!revisionURI.equals(uriExpected)) {
      System.out.println(revisionURI + " != " + uriExpected);
      assertTrue(false);
    }

    uriExpected = "textgrid:12345.15";
    uri = "textgrid:12345.15";
    revisionURI = OAIPMHUtilities.getTextGridRevisionURI(uri);
    if (!revisionURI.equals(uriExpected)) {
      System.out.println(revisionURI + " != " + uriExpected);
      assertTrue(false);
    }
  }

}
